package cz.fidentis.analyst.symmetry;

import static cz.fidentis.analyst.gui.UserInterface.frameMain;
import cz.fidentis.analyst.canvas.Canvas;
import cz.fidentis.analyst.scene.DrawablePlane;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.ImageIcon;
import javax.swing.JCheckBox;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JToggleButton;

/**
 * Action listener for the manipulation with the symmetry plane.
 * 
 * @author Radek Oslejsek
 */
public class SymmetryPlaneAction extends AbstractAction {
    
    public static final String ACTION_COMMAND_SHOW_HIDE_PLANE = "show-hide symmetry plane";
    public static final String ACTION_COMMAND_SHOW_HIDE_PANEL = "show-hide control panel";
    public static final String ACTION_COMMAND_RECOMPUTE = "recompute";
    
    private final SymmetryPanel controlPanel;
    private final JPanel topControlPanel;
    private final Canvas canvas;
    
    /**
     * Constructor.
     * 
     * @param topControlPanel Top component for placing control panels
     * @param canvas OpenGL canvas
     */
    public SymmetryPlaneAction(JPanel topControlPanel, Canvas canvas) {
        this.canvas = canvas;
        this.controlPanel = new SymmetryPanel(this);
        this.topControlPanel = topControlPanel;
        this.topControlPanel.add(controlPanel);
        controlPanel.setVisible(false);
    }
    
    @Override
    public void actionPerformed(ActionEvent ae) {
        String action = ae.getActionCommand();
        DrawablePlane plane;
        
        switch (action) {
            case ACTION_COMMAND_SHOW_HIDE_PLANE:
                plane = canvas.getScene().getDrawableSymmetryPlane(0);
                if (((JToggleButton) ae.getSource()).isSelected()) {
                    if (plane == null) {
                        recomputeSymmetryPlane();
                    }
                    plane.show();
                } else {
                    if (plane != null) {
                       plane.hide();
                    }
                }
                break;
            case ACTION_COMMAND_SHOW_HIDE_PANEL:
                controlPanel.setVisible(((JToggleButton) ae.getSource()).isSelected());
                break;
            case ACTION_COMMAND_RECOMPUTE: 
                recomputeSymmetryPlane();
                canvas.getScene().getDrawableSymmetryPlane(0).show();
                break;  
            default:
                throw new UnsupportedOperationException(action);
        }
        canvas.renderScene();
    }
    
    private void recomputeSymmetryPlane() {
        //setCursor(Cursor.getPredefinedCursor(Cursor.CROSSHAIR_CURSOR));
        controlPanel.confirmConfigParams();
        SymmetryEstimator se = new SymmetryEstimator(controlPanel.getSymmetryConfig());
        canvas.getScene().getDrawableFace(0).getModel().compute(se);
        DrawablePlane plane = new DrawablePlane(se.getSymmetryPlaneMesh(), se.getSymmetryPlane());
        canvas.getScene().setDrawableSymmetryPlane(0, plane);
    }
    
}
